@@ -59,6 +59,9 @@
 }
 
 #include <media/v4l2-common.h>
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 27)
+#include <media/v4l2-ioctl.h>
+#endif
 
 /* --------------------------------- */
 /* DEFINES FOR OV511 AND OTHER CHIPS */
